gb_detect_cache_dir: Detect the 'geobounds' cache directory

View source: R/gb-cache.R

gb_detect_cache_dirR Documentation

Detect the geobounds cache directory

Description

Detects the active cache directory. See gb_set_cache_dir().

Usage

gb_detect_cache_dir(x = NULL)

Arguments

x

An object. Ignored.

Value

A character scalar containing the path to the active cache directory. The path is also printed as a clickable message. See cli::inline-markup from cli.

See Also

Cache management functions: gb_clear_cache(), gb_set_cache_dir()

Examples

gb_detect_cache_dir()

geobounds documentation built on Sept. 6, 2026, 1:06 a.m.