Skip to contents

Detects the active cache directory. See gb_set_cache_dir().

Usage

gb_detect_cache_dir(x = NULL)

Arguments

x

An object. Ignored.

Value

A character scalar containing the path to the active cache directory. The path is also printed as a clickable message. See cli::inline-markup from cli.

See also

Cache management functions: gb_clear_cache(), gb_set_cache_dir()

Examples

gb_detect_cache_dir()
#>  /tmp/RtmpMujlMf/geobounds
#> [1] "/tmp/RtmpMujlMf/geobounds"