Detects the active cache directory. See gb_set_cache_dir().
Value
A character scalar containing the path to the active cache directory. The path is also printed as a clickable message. See cli::inline-markup from cli.
See also
Cache management functions:
gb_clear_cache(),
gb_set_cache_dir()