Skip to contents

Detect the current cache folder. See gb_set_cache_dir().

Usage

gb_detect_cache_dir(x = NULL)

Arguments

x

Ignored.

Value

A character vector with the path to your cache_dir. The same path also appears as a clickable message. See cli::inline-markup.

See also

Other cache utilities: gb_clear_cache(), gb_set_cache_dir()

Examples

gb_detect_cache_dir()
#>  /tmp/Rtmp0UvivY/geobounds
#> [1] "/tmp/Rtmp0UvivY/geobounds"