| gb_detect_cache_dir | R Documentation |
Detects the active cache directory. See gb_set_cache_dir().
gb_detect_cache_dir(x = NULL)
x |
An object. Ignored. |
A character scalar containing the path to the active cache directory. The path is also printed as a clickable message. See cli::inline-markup from cli.
Cache management functions:
gb_clear_cache(),
gb_set_cache_dir()
gb_detect_cache_dir()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.